==> 0.0.1.tar.gz: example/lib/pages/fieldList.dart <==
import 'package:flutter/material.dart';
import 'package:millui/millui.dart';

class Fieldlist extends StatefulWidget {
  _Fieldlist createState() => new _Fieldlist();
}

class _Fieldlist extends State<Fieldlist> {
  String _text = '默认值';

  TextEditingController mControll = TextEditingController();
  @override
  void initState() {
    mControll.text = _text;
    super.initState();
  }

  @override
  void dispose() {
    mControll.dispose();
    super.dispose();
  }

  _alert() {
    MillDialog.tip(context, message: 'ok');
  }

  onChanged(text) {
    setState(() {
      _text = text;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('field'),
      ),
      body: Container(
        child: ListView(
          children: <Widget>[
            Container(
              padding: EdgeInsets.all(20),
              child: Text('基础用法'),
            ),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(),
            ),
            Padding(padding: EdgeInsets.only(top: 5)),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(
                suffixIcon: Icon(
                  Icons.warning,
                  size: 16,
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(20),
              child: Text('只读'),
            ),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(
                readonly: true,
                readBox: Text('只读'),
                suffixIcon: Icon(
                  Icons.warning,
                  size: 16,
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(20),
              child: Text('只读点击事件'),
            ),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(
                readonly: true,
                readBox: GestureDetector(
                  onTap: _alert,
                  child: Text('只读'),
                ),
                suffixIcon: Icon(
                  Icons.keyboard_arrow_right,
                  size: 26,
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(20),
              child: Text('label icon'),
            ),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(
                prefixIcon: Icon(
                  Icons.supervised_user_circle,
                  size: 16,
                ),
                suffixIcon: Icon(
                  Icons.warning,
                  size: 16,
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(20),
              child: Text('使用控制器'),
            ),
            Container(
              padding: EdgeInsets.all(10),
              child: Text('当前值：$_text'),
            ),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(
                onChanged: onChanged,
                controller: mControll,
                prefixIcon: Icon(
                  Icons.supervised_user_circle,
                  size: 16,
                ),
                suffixIcon: GestureDetector(
                  onTap: () {
                    mControll.clear();
                  },
                  child: Icon(
                    Icons.close,
                    size: 16,
                  ),
                ),
              ),
            ),
            Padding(padding: EdgeInsets.only(top: 20))
          ],
        ),
      ),
    );
  }
}

==> 0.0.3.tar.gz: example/lib/pages/fieldList.dart <==
import 'package:flutter/material.dart';
import 'package:millui/millui.dart';

import '../app_provider.dart';

class Fieldlist extends StatefulWidget {
  _Fieldlist createState() => new _Fieldlist();
}

class _Fieldlist extends State<Fieldlist> {
  String _text = 'Default';

  TextEditingController mControll = TextEditingController();
  @override
  void initState() {
    mControll.text = 'Default';
    super.initState();
  }

  @override
  void dispose() {
    mControll.dispose();
    super.dispose();
  }

  _alert() {
    MillDialog.tip(context, message: 'ok');
  }

  onChanged(text) {
    setState(() {
      _text = text;
    });
  }

  @override
  Widget build(BuildContext context) {
    bool isCn = getLanage(context);

    return Scaffold(
      appBar: AppBar(
        title: Text('field'),
      ),
      body: Container(
        child: ListView(
          children: <Widget>[
            Container(
              padding: EdgeInsets.all(20),
              child: Text(isCn ? '基础用法' : 'Basic'),
            ),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(hintText: 'tips', label: 'Label'),
            ),
            Padding(padding: EdgeInsets.only(top: 5)),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(
                hintText: 'tips',
                label: 'Label',
                suffixIcon: Icon(
                  Icons.warning,
                  size: 16,
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(20),
              child: Text(isCn ? '只读' : 'Readonly'),
            ),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(
                label: 'Label',
                readonly: true,
                readBox: Text(isCn ? '只读' : 'Readonly'),
                suffixIcon: Icon(
                  Icons.warning,
                  size: 16,
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(20),
              child: Text(isCn ? '只读点击事件' : 'onClick'),
            ),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(
                label: 'Label',
                readonly: true,
                readBox: GestureDetector(
                  onTap: _alert,
                  child: Text(isCn ? '只读' : 'Readonly'),
                ),
                suffixIcon: Icon(
                  Icons.keyboard_arrow_right,
                  size: 26,
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(20),
              child: Text('label icon'),
            ),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(
                label: 'Label+Icon',
                hintText: 'placeholder',
                prefixIcon: Icon(
                  Icons.supervised_user_circle,
                  size: 16,
                ),
                suffixIcon: Icon(
                  Icons.warning,
                  size: 16,
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(20),
              child: Text(isCn ? '使用控制器' : 'Controller'),
            ),
            Container(
              padding: EdgeInsets.all(10),
              child: Text(isCn ? '当前值：$_text' : 'Value：$_text'),
            ),
            Container(
              color: Color(0xffffffff),
              padding: EdgeInsets.only(left: 10, right: 10),
              child: MillField(
                label: 'Label',
                onChanged: onChanged,
                controller: mControll,
                prefixIcon: Icon(
                  Icons.supervised_user_circle,
                  size: 16,
                ),
                suffixIcon: GestureDetector(
                  onTap: () {
                    mControll.clear();
                  },
                  child: Icon(
                    Icons.close,
                    size: 16,
                  ),
                ),
              ),
            ),
            Padding(padding: EdgeInsets.only(top: 20))
          ],
        ),
      ),
    );
  }
}
